==> zezis_widget-0.2.50.tar.gz: lib/z_check/z_check_box_custom.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class ZCheckBoxCustom extends StatelessWidget {
  final bool value;
  final String label;
  final double? space;
  final Widget? content;
  final Function()? onTap;
  final Function(bool?)? onChanged;

  final Color? color;
  final Color? checkColor;
  final Color? activeColor;

  final EdgeInsetsGeometry? padding;
  final EdgeInsetsGeometry? contentPadding;
  
  const ZCheckBoxCustom({
    super.key,

    this.space,
    this.value = false,
    this.label = "",
    this.content,
    this.onTap,
    this.onChanged,

    this.color,
    this.checkColor,
    this.activeColor,

    this.padding,
    this.contentPadding,
  });

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Padding(
        padding: padding ?? const EdgeInsets.all(8.0),
        child: Row(
          children: [
            SizedBox(
              height: 24,
              width: 24,
              child: Checkbox(
                value: value,
                onChanged: onChanged,
                shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(5)),

                checkColor: checkColor,
                activeColor: activeColor,
              ),
            ),

            SizedBox(width: space),

            InkWell(
              onTap: onTap,
              child: content ?? Container(
                padding: contentPadding ?? const EdgeInsets.only(left: 16),
                child: Text(
                  label,
                  style: GoogleFonts.roboto(),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> zezis_widget-0.2.51.tar.gz: lib/z_check/z_check_box_custom.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class ZCheckBoxCustom extends StatelessWidget {
  final bool value;
  final String label;
  final double? space;
  final double border;
  final Widget? content;
  final Function()? onTap;
  final Function(bool?)? onChanged;

  final Color? color;
  final Color? checkColor;
  final Color? activeColor;

  final EdgeInsetsGeometry? padding;
  final EdgeInsetsGeometry? contentPadding;
  
  const ZCheckBoxCustom({
    super.key,

    this.space,
    this.border = 5,
    this.value = false,
    this.label = "",
    this.content,
    this.onTap,
    this.onChanged,

    this.color,
    this.checkColor,
    this.activeColor,

    this.padding,
    this.contentPadding,
  });

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Padding(
        padding: padding ?? const EdgeInsets.all(8.0),
        child: Row(
          children: [
            SizedBox(
              height: 24,
              width: 24,
              child: Checkbox(
                value: value,
                onChanged: onChanged,
                checkColor: checkColor,
                activeColor: activeColor,
                shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(border)),
              ),
            ),
      
            SizedBox(width: space),
      
            content ?? Expanded(
              child: Text(
                label,
                
                textAlign: TextAlign.left,
                overflow: TextOverflow.clip,

                style: GoogleFonts.roboto(
                  fontWeight: value ? FontWeight.bold : FontWeight.normal,
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
